#!/usr/bin/env python
#
# Copyright © 2016-2020 - Rennes Physics Institute
#
# This file is part of msspec.
#
# msspec is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
# msspec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this msspec.  If not, see <http://www.gnu.org/licenses/>.
#
# Source file  : src/msspec/version.py
# Last modified: Thu, 06 Oct 2022 18:19:16 +0200
# Committed by : Sylvain Tricot <sylvain.tricot@univ-rennes1.fr> 1665073156 +0200


import os

from importlib.metadata import version
import subprocess

# find the version number
# 1- If it fails, try to read it from the distribution file
# 2- Try to read it from the git info
# 3- If it fails, try to read it from the VERSION file

PKGNAME = 'msspec'

try:
    __version__ = version(PKGNAME)
except Exception as err:
    try:
        p = subprocess.run(["git", "describe"], capture_output=True, text=True)
        if p.stdout not in ("", None):
            __version__ = p.stdout.strip()
        else:
            raise NameError("git describe failed!")
    except Exception as err:
        try:
            thisfile_path = os.path.abspath(__file__)
            thisfile_dir = os.path.dirname(thisfile_path)
            versionfile = os.path.join(thisfile_dir, "../VERSION")
            with open(versionfile, "r") as fd:
                __version__ = fd.readline().strip()
        except Exception as err:
            print("Unable to get the version number!")
            __version__ = "9.9.9"
